@@ -2,7 +2,6 @@ setMethod("asJSON", "array", function(x, collapse = TRUE, na = NULL, oldna = NUL
   matrix = c("rowmajor", "columnmajor"), auto_unbox = FALSE, keep_vec_names = FALSE,
   indent = NA_integer_, ...) {
 
-  #validate
   matrix <- match.arg(matrix);
 
   # reset na arg when called from data frame
@@ -10,11 +9,26 @@ setMethod("asJSON", "array", function(x, collapse = TRUE, na = NULL, oldna = NUL
     na <- oldna;
   }
 
+  # 1D arrays are vectors
+  if(length(dim(x)) < 2){
+    return(asJSON(c(x), matrix = matrix, na = na, indent = indent + 2L, ...))
+  }
+
   # if collapse == FALSE, then this matrix is nested inside a data frame,
-  # and therefore row major is required to match dimensions
+  # and therefore row major must be forced to match dimensions
+  if(identical(matrix, "columnmajor") && collapse == FALSE){
+    return(apply(x, 1, asJSON, matrix = matrix, na = na, indent = indent + 2L, ...))
+  }
+
   # dont pass auto_unbox (never unbox within matrix)
-  margin <- ifelse(identical(matrix, "columnmajor") && isTRUE(collapse), length(dim(x)), 1);
-  tmp <- apply(x, margin, asJSON, matrix = matrix, na = na, indent = indent + 2L, ...)
+  m <- asJSON(c(x), collapse = FALSE, matrix = matrix, na = na, ...)
+  dim(m) <- dim(x)
+  tmp <- if(length(dim(x)) == 2 && identical(matrix, "rowmajor")){
+    # Faster special case for 2D matrices
+    row_collapse(m, indent = indent + 2L)
+  } else {
+    collapse_array(m, columnmajor = identical(matrix, "columnmajor"), indent = indent)
+  }
 
   # collapse it
   if (collapse) {
